Parse Module
Parse active patterns — match and extract parsed values from strings.
Active patterns
| Active pattern |
Description
|
Full Usage:
(|Bool|_|) str
Parameters:
string
Returns: bool option
|
Matches a string that parses as a bool, extracting the value. The string to parse.
|
|
Matches a string that parses as a DateTimeOffset, extracting the value. The string to parse.
|
Full Usage:
(|Decimal|_|) str
Parameters:
string
Returns: decimal option
|
Matches a string that parses as a decimal, extracting the value. The string to parse.
|
Full Usage:
(|Double|_|) str
Parameters:
string
Returns: float option
|
Matches a string that parses as a double, extracting the value. The string to parse.
|
|
Matches a string that parses as a Guid, extracting the value. The string to parse.
|
Full Usage:
(|Int64|_|) str
Parameters:
string
Returns: int64 option
|
Matches a string that parses as an int64, extracting the value. The string to parse.
|
Full Usage:
(|Int|_|) str
Parameters:
string
Returns: int option
|
Matches a string that parses as an int32, extracting the value. The string to parse.
|
TDesu.FSharp