Header menu logo TDesu.FSharp

ArrayPool Module

Functions and values

Function or value Description

ArrayPool.rentBytes minLength

Full Usage: ArrayPool.rentBytes minLength

Parameters:
    minLength : int

Returns: byte[]
Modifiers: inline

Rents a byte buffer from the shared pool. The minimum length of the rented buffer.

minLength : int
Returns: byte[]

ArrayPool.returnBytes arr

Full Usage: ArrayPool.returnBytes arr

Parameters:
    arr : byte[]

Modifiers: inline

Returns a byte buffer to the shared pool. The byte array to return to the pool.

arr : byte[]

ArrayPool.useBytes minLength f

Full Usage: ArrayPool.useBytes minLength f

Parameters:
    minLength : int
    f : byte[] -> 'R

Returns: 'R
Modifiers: inline
Type parameters: 'R

Rents a byte buffer, applies f, then returns the buffer to the pool. The minimum length of the rented buffer. The function to apply to the rented buffer.

minLength : int
f : byte[] -> 'R
Returns: 'R

ArrayPool.usePooled minLength f

Full Usage: ArrayPool.usePooled minLength f

Parameters:
    minLength : int
    f : 'T[] -> 'R

Returns: 'R
Modifiers: inline
Type parameters: 'T, 'R

Rents a typed buffer from the shared pool, applies f, then returns the buffer. The minimum length of the rented buffer. The function to apply to the rented buffer.

minLength : int
f : 'T[] -> 'R
Returns: 'R

ArrayPool.withCopy data offset length f

Full Usage: ArrayPool.withCopy data offset length f

Parameters:
    data : byte[]
    offset : int
    length : int
    f : byte[] -> 'R

Returns: 'R
Modifiers: inline
Type parameters: 'R

Rents a buffer, copies data into it, applies f, then returns the buffer. The source byte array to copy from. The starting offset in the source array. The number of bytes to copy. The function to apply to the copied buffer.

data : byte[]
offset : int
length : int
f : byte[] -> 'R
Returns: 'R

Type something to start searching.