Header menu logo TDesu.FSharp

Signal Type

One-shot async signal. Wraps TaskCompletionSource{T} for idiomatic F# async coordination.

Thread-safe — uses RunContinuationsAsynchronously to avoid inline continuations.

Constructors

Constructor Description

Signal()

Full Usage: Signal()

Returns: Signal
Returns: Signal

Instance members

Instance member Description

this.IsSet

Full Usage: this.IsSet

Returns: bool

Whether the signal has been set.

Returns: bool

this.Set

Full Usage: this.Set

Completes the signal, releasing all waiters. Idempotent.

this.Wait

Full Usage: this.Wait

Parameters:
Returns: Task<bool>

Returns a task that completes when the signal is set, with a timeout. Returns true if signaled, false if timed out. The maximum duration to wait for the signal.

timeout : TimeSpan
Returns: Task<bool>

this.Wait

Full Usage: this.Wait

Returns: Task

Returns a task that completes when the signal is set.

Returns: Task

Type something to start searching.