Header menu logo TDesu.FSharp

TDesu.FSharp.IO Namespace

I/O utilities: Env, File, Directory, Disposable (deferStack), TemporaryFileStream.

Type/Module Description

Directory

Disposable

Disposable utilities — create, combine, defer, null-safe dispose.

Env

Environment variable helpers.

File

Path (Module)

Path (Type)

Static helper for path utilities.

TemporaryFileStream

A Stream backed by a temporary file that is deleted on Dispose (unless opted out). Optional path for the temporary file; defaults to a system-generated temp file name. When true, the backing file is kept on disk after Dispose.

Type something to start searching.