Header menu logo TDesu.FSharp

Stream.MaxBytesExceeded Type

The outcome of copyUpTo when the source produced more bytes than the configured limit.

Record fields

Record Field Description

BytesWritten

Full Usage: BytesWritten

Field type: int64

The number of bytes actually written to the destination before the limit was hit.

Field type: int64

MaxBytes

Full Usage: MaxBytes

Field type: int64

The configured maximum number of bytes was allowed to read.

Field type: int64

Type something to start searching.