Header menu logo TDesu.FSharp

TemporaryFileStream Type

A Stream backed by a temporary file that is deleted on Dispose (unless opted out). Optional path for the temporary file; defaults to a system-generated temp file name. When true, the backing file is kept on disk after Dispose.

Constructors

Constructor Description

TemporaryFileStream(?tempFileName, ?doNotDeleteFileAfterDispose)

Full Usage: TemporaryFileStream(?tempFileName, ?doNotDeleteFileAfterDispose)

Parameters:
    ?tempFileName : string
    ?doNotDeleteFileAfterDispose : bool

Returns: TemporaryFileStream
?tempFileName : string
?doNotDeleteFileAfterDispose : bool
Returns: TemporaryFileStream

Instance members

Instance member Description

this.FileName

Full Usage: this.FileName

Returns: string

Gets the full path of the temporary file backing this stream.

Returns: string

Type something to start searching.