Header menu logo TDesu.FSharp

String Module

Active patterns

Active pattern Description

(|EmptyOrWhiteSpace|_|) str

Full Usage: (|EmptyOrWhiteSpace|_|) str

Parameters:
    str : string

Returns: unit option

Matches when the string is empty or contains only whitespace. Does not match null. The string to test.

str : string
Returns: unit option

(|Empty|_|) str

Full Usage: (|Empty|_|) str

Parameters:
    str : string

Returns: unit option

Matches when the string has zero length. Does not match null. The string to test.

str : string
Returns: unit option

(|NullOrWhiteSpace|_|) str

Full Usage: (|NullOrWhiteSpace|_|) str

Parameters:
    str : string

Returns: unit option

Matches when the string is null, empty, or whitespace. The string to test.

str : string
Returns: unit option

(|StartsWithAny|_|) values str

Full Usage: (|StartsWithAny|_|) values str

Parameters:
    values : string[]
    str : string

Returns: unit option

Matches when the string starts with any of the given values. The prefixes to check against. The string to test.

values : string[]
str : string
Returns: unit option

(|WhiteSpaces|_|) str

Full Usage: (|WhiteSpaces|_|) str

Parameters:
    str : string

Returns: unit option

Matches when the string contains only whitespace characters and has length > 1. Does not match null. The string to test.

str : string
Returns: unit option

(|WhiteSpace|_|) str

Full Usage: (|WhiteSpace|_|) str

Parameters:
    str : string

Returns: unit option

Matches when the string is exactly a single whitespace character. Does not match null. The string to test.

str : string
Returns: unit option

Type something to start searching.