String Module
Active patterns
| Active pattern |
Description
|
Full Usage:
(|EmptyOrWhiteSpace|_|) str
Parameters:
string
Returns: unit option
|
Matches when the string is empty or contains only whitespace. Does not match null. The string to test.
|
Full Usage:
(|Empty|_|) str
Parameters:
string
Returns: unit option
|
Matches when the string has zero length. Does not match null. The string to test.
|
Full Usage:
(|NullOrWhiteSpace|_|) str
Parameters:
string
Returns: unit option
|
Matches when the string is null, empty, or whitespace. The string to test.
|
Full Usage:
(|StartsWithAny|_|) values str
Parameters:
string[]
str : string
Returns: unit option
|
Matches when the string starts with any of the given values. The prefixes to check against. The string to test.
|
Full Usage:
(|WhiteSpaces|_|) str
Parameters:
string
Returns: unit option
|
Matches when the string contains only whitespace characters and has length > 1. Does not match null. The string to test.
|
Full Usage:
(|WhiteSpace|_|) str
Parameters:
string
Returns: unit option
|
Matches when the string is exactly a single whitespace character. Does not match null. The string to test.
|
TDesu.FSharp