Array Module
Array extensions: stream conversion and allocation-free ValueOption lookups.
Functions and values
| Function or value |
Description
|
Full Usage:
Array.ofMemoryStream memoryStream
Parameters:
MemoryStream
Returns: byte[]
Modifiers: inline |
Converts a
|
Full Usage:
Array.valueChooseFirst chooser array
Parameters:
'T -> 'U voption
-
The function applied to each element; the first ValueSome result is returned.
array : 'T[]
-
The array to search.
Returns: 'U voption
Modifiers: inline Type parameters: 'T, 'U |
Applies chooser to each element from the start and returns the first
|
Full Usage:
Array.valueChooseLast chooser array
Parameters:
'T -> 'U voption
-
The function applied to each element; the first ValueSome result is returned.
array : 'T[]
-
The array to search.
Returns: 'U voption
Modifiers: inline Type parameters: 'T, 'U |
Applies chooser to each element from the end and returns the first
|
Full Usage:
Array.valueTryFind filter array
Parameters:
'T -> bool
-
The predicate to test each element.
array : 'T[]
-
The array to search.
Returns: 'T voption
Modifiers: inline Type parameters: 'T |
Returns the first element satisfying filter as
|
Full Usage:
Array.valueTryFindLast filter array
Parameters:
'T -> bool
-
The predicate to test each element.
array : 'T[]
-
The array to search.
Returns: 'T voption
Modifiers: inline Type parameters: 'T |
Returns the last element satisfying filter as
|
TDesu.FSharp