Stack Module
Functions and values
| Function or value |
Description
|
Removes and returns the top element from the stack.
A null
|
|
Full Usage:
push item stack
Parameters:
'T
stack : Stack<'T>
Modifiers: inline Type parameters: 'T |
Pushes an item onto the top of the stack.
|
|
|
Full Usage:
tryPeek stack
Parameters:
Stack<'T>
Returns: 'T option
Modifiers: inline Type parameters: 'T |
Returns the top element as Some, or None if the stack is empty or null. The stack to peek into.
|
TDesu.FSharp