Header menu logo TDesu.FSharp

Stack Module

Functions and values

Function or value Description

pop stack

Full Usage: pop stack

Parameters:
Returns: 'T
Modifiers: inline
Type parameters: 'T

Removes and returns the top element from the stack. The stack to pop from.

stack : Stack<'T>
Returns: 'T

push item stack

Full Usage: push item stack

Parameters:
    item : 'T
    stack : Stack<'T>

Modifiers: inline
Type parameters: 'T

Pushes an item onto the top of the stack. The item to push. The stack to push onto.

item : 'T
stack : Stack<'T>

reverse stack

Full Usage: reverse stack

Parameters:
Returns: Stack<'T>

Returns a new stack with elements in reverse order. The stack to reverse.

stack : Stack<'T>
Returns: Stack<'T>

tryPeek stack

Full Usage: tryPeek stack

Parameters:
Returns: 'T option
Modifiers: inline
Type parameters: 'T

Returns the top element as Some, or None if the stack is empty. The stack to peek into.

stack : Stack<'T>
Returns: 'T option

Type something to start searching.